#!/usr/bin/python
# -*- coding: utf-8 -*-

#widgetsqt.py: Todas aquellas clases que heredan directamente de algun widget de Qt y que pretenden aumentar su funcionalidad

#Copyright (C) 2006  Inmaculada Luengo Merino, Nstor Arocha Rodrguez
#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

#Fichero de libreria de qt
from qt import *
from qttable import *


#http://www.digitalfanatics.org/projects/qt_tutorial/chapter13.html
#Mirar de http://www.handhelds.org/~zecke/apidocs/libopie/html/ocheckitem_8cpp-source.html
#Mirar tablestatistics.py de ejemplos de PyQT

class ButtonTableItem(QTableItem):
	"""Esta clase hereda de QTableItem. Modifica dos aspectos de estos:
		Por un lado inhabilita el texto que muestra normalmente
		Por otro, utiliza un botón para que al ser pulsado lanza el dialogo de casos
		"""

	def __init__(self,tabla,dcasos):
		"""la inicialización llama al padre"""
		QTableItem.__init__(self,tabla,QTableItem.WhenCurrent,"...") 
		self.setReplaceable(False)
		self.__dcasos=dcasos

	#FUNCIONES PUBLICAS
		
	def createEditor(self):
		"""Crea un editor para interactuar con el contenido.
		En este caso es un botón, ya que permite asignar una acción al click de ratón"""
		boton=QButton(self.table().viewport(),"Ventana abierta") #El padre es viewport, es invisible
		QObject.connect(boton,SIGNAL("clicked()"),self.__editar)
		QObject.connect(boton,SIGNAL("clicked()"),self.table(), SLOT("doValueChanged()"))
		return boton

	def setContentFromEditor(self,widget):
		"""Cuando el contenido de widget cambia, qt llama a esta función.
		Esta desactivada ya que el botón que actua de editor no dispone de información para devolver"""
		pass

	#FUNCIONES PRIVADAS
	def __editar(self):
		"""Abre el dialogo de casos, pasando la columna como valor"""
		self.__dcasos.show(self.row())


#TODO: Clases candidatas a abstraccion. Podria definirse un QComboBox con un metodo para rellenar valores, y que estas dos clases heredasen de la primera. Se podria garantizar mejor el que la clase mantenga el valor seleccionado con un show

class ComboBoxVars(QComboBox):
	"""ComboBox modificado que devuelve siempre una lista de variables actualizadas"""
	def __init__(self,parent,datos,factores=True):
		QComboBox.__init__(self,parent,"comboboxvars")
		self.__datos=datos
		self.__factores=factores
		
	def show(self):
		"""Redefine el show de QComboBox, añadiendo el listado de variables"""
		#texto=self.currentText()
		self.clear()
		for variable in self.__datos.arrTit(factores=self.__factores):
			self.insertItem(variable)
		#self.setCurrentText(texto) #TODO: dejar marcado el item que estaba
		QComboBox.show(self)

class ComboBoxFact(QComboBox):
	"""ComboBox modificado que devuelve siempre una lista de variables actualizadas"""
	def __init__(self,parent,datos):
		self.__datos=datos
		QComboBox.__init__(self,parent,"comboboxfact")
		
	def show(self):
		"""Redefine el show de QComboBox, añadiendo el listado de variables"""
		#texto=self.currentText()
		self.clear()
		for variable in self.__datos.arrTit(tipo="Factor"):
			self.insertItem(variable)
		#self.setCurrentText(texto) #TODO: dejar marcado el item que estaba
		QComboBox.show(self)

class QGridButtonGroup(QButtonGroup):
	"""Reimplementación de QButtonGroup que organiza los botones de forma que ocupen lo menos posible
		Actualmente solo añade un QGridLayout de 2 columnas
	"""
	def __init__(self,parent,nombre):
		QButtonGroup.__init__(self,parent,"SeleccionMultiple")
		self.setGeometry(QRect(110,80,170,121))
		self.setColumnLayout(0,Qt.Vertical)
		self.layout().setSpacing(6)
		self.layout().setMargin(11)
		self.layout=QGridLayout(self.layout(),2)
		self.x=0
		self.y=0

	def insert(self,boton):
		QButtonGroup.insert(self,boton)
		self.layout.addWidget(boton,self.x,self.y)
		if self.y==0:
			self.y=1
		else:
			self.x+=1
			self.y=0

